package airlift.test.util;

/**
 * Title:        AirLift Framework for Java - Test Project
 * Description:  A simple unit test of concrete Enumerates including performance testing.
 * Copyright:    Copyright (c) 2002
 *                  Note: this file is hereby released for reference use
 *                  to participants in the Middle Tennessee Java Users Group.
 * Company:      The AirLift Team
 * @author       Mark Soileau
 * @version      1.0
 */

import airlift.util.Enumerate;
import java.util.*;

public class EnumerateTester
{
    // note: we have not configured a valid logger for "airlift.test.util" so we get
    // the default "root" Logger from the LogManager
    // The idea here is to allow routing of log events at the package (or more detailed) level.
    //public static Logger mLogger = LogManager.getLogManager().getLogger("airlift.test.util");

    // static classname (without package details) used for logging
    //public static String mClassDesc = "EnumerateTester";

    // Removed Logger/LogManager use above for simpler distribution of example code..

    public EnumerateTester()
        {
        }

    /**
     * Run a test using a couple of test Enumerate concrete classes
     */
    public void runTest()
        {

        /*long start = System.currentTimeMillis();
        System.out.println("Starting bitwise test with bytes..");
        byte bA,bB,bC,bD;
        for (int i = 0; i < 100000000; i++)
            {
            bA = 16;
            bB = 32;
            bC = 33;
            bD = (byte)(bA & bB);
            bD = (byte)(bC | bB);
            if (bB > bA)
                 bD = (byte)(bC & bB | bA);
            }
        System.out.println("Ended bitwise test with bytes:" + (System.currentTimeMillis() - start));

        long startI = System.currentTimeMillis();
        System.out.println("Starting bitwise test with ints..");
        int iA,iB,iC,iD;
        for (int i = 0; i < 100000000; i++)
            {
            iA = 16;
            iB = 32;
            iC = 33;
            iD = iA & iB;
            iD = iC | iB;
            if (iB > iA)
                 iD = iC & iB | iA;
            }
        System.out.println("Ended bitwise test with ints:" + (System.currentTimeMillis() - startI));
        */

        // test iterator across all ViewportRoles ordinant instances
        System.out.println("\nTest iterate over ViewportRoles.");
        Iterator iter = ViewportRoles.ALL.iterate();
        while (iter.hasNext())
            {
            ViewportRoles enum = (ViewportRoles)iter.next();
            System.out.println("  Iteration of ViewportRoles: name = \"" + enum.getName() +
                                "\", index = " + enum.getIndex());

            }

        // test locating ViewportRoles by String name
        System.out.println("\nFind ViewportRole by name (\"RESULTS\").");
        ViewportRoles enum = (ViewportRoles) ViewportRoles.ALL.findByName("RESULTS");
        if (enum != null)
            {
            System.out.println("  Found from ViewportRoles: name = \"" + enum.getName() +
                                "\", index = " + enum.getIndex());
            }

        // test locating ViewportRoles by int index
        System.out.println("\nFind ViewportRole by index (4).");
        enum = (ViewportRoles) ViewportRoles.ALL.get(4);
        if (enum != null)
            {
            System.out.println("  Found from ViewportRoles: name = \"" + enum.getName() +
                                "\", index = " + enum.getIndex());
            }

        System.out.println("\nCompare reference against ViewportRoles.RESULTS");
        if (enum == ViewportRoles.RESULTS)
            {
            System.out.println("  Matches with RESULTS.");
            }
        else {
            System.out.println("  Did not match with RESULTS.");
            }

        System.out.println("\nCompare reference against ViewportRoles.LIST");
        if (enum == ViewportRoles.LIST)
            {
            System.out.println("  Matches with LIST.");
            }
        else {
            System.out.println("  Did not match with LIST.");
            }

        // Do some performance testing against alternate identity mechanisms

         // lookup N times for each performance test case
        int iterations = 10000000;

         // First build a HashMap containing all the WidgetType names
         // and test the speed of N attempts to get the RenderHints for
         // a specified WidgetType
        HashMap widgetTypeMapByName = new HashMap(WidgetTypes.ALL.getSize() * 2);
        iter = WidgetTypes.ALL.iterate();
        while (iter.hasNext())
            {
            WidgetTypes widgetType = (WidgetTypes)iter.next();
            widgetTypeMapByName.put(widgetType.getName(),widgetType);
            }

        long start = System.currentTimeMillis();
        System.out.println("\nLooking up RenderHints by WidgetType hashed on String name..");

        for (int i = 0; i < iterations; i++)
            {
            WidgetTypes widgetType = (WidgetTypes)widgetTypeMapByName.get("COMBO_BOX");
            Object renderHints = widgetType.getDefaultRenderHints();
            widgetType = (WidgetTypes)widgetTypeMapByName.get("SELECT_LIST");
            renderHints = widgetType.getDefaultRenderHints();
            widgetType = (WidgetTypes)widgetTypeMapByName.get("FORM");
            renderHints = widgetType.getDefaultRenderHints();
            }

        System.out.println("  Required:" + (System.currentTimeMillis() - start)
                            + " millis.");

         // Next build an ArrayList containing all the WidgetTypes by index
         // and test the speed of N attempts to get the RenderHints for
         // a specified WidgetType if we know the index
        ArrayList widgetTypeArrayList = new ArrayList(WidgetTypes.ALL.getSize());
        iter = WidgetTypes.ALL.iterate();
        while (iter.hasNext())
            {
            WidgetTypes widgetType = (WidgetTypes)iter.next();
            widgetTypeArrayList.add(widgetType);
            }

        start = System.currentTimeMillis();
        System.out.println("\nLooking up RenderHints by WidgetType index within Arraylist..");

        for (int i = 0; i < iterations; i++)
            {
            WidgetTypes widgetType = (WidgetTypes)widgetTypeArrayList.get(6);
            Object renderHints = widgetType.getDefaultRenderHints();
            widgetType = (WidgetTypes)widgetTypeArrayList.get(7);
            renderHints = widgetType.getDefaultRenderHints();
            widgetType = (WidgetTypes)widgetTypeArrayList.get(8);
            renderHints = widgetType.getDefaultRenderHints();
            }

        System.out.println("  Required:" + (System.currentTimeMillis() - start)
                            + " millis.");


        // now just ask for the default render hints through the static Enumerate
        start = System.currentTimeMillis();
        System.out.println("\nLooking up RenderHints through WidgetType Enumerate..");

        for (int i = 0; i < iterations; i++)
            {
            Object renderHints = WidgetTypes.COMBO_BOX.getDefaultRenderHints();
            renderHints = WidgetTypes.SELECT_LIST.getDefaultRenderHints();
            renderHints = WidgetTypes.FORM.getDefaultRenderHints();
            }

        System.out.println("  Required:" + (System.currentTimeMillis() - start)
                            + " millis.");

        }


    public static void main(String[] args)
        {
        EnumerateTester tester1 = new EnumerateTester();
        tester1.runTest();
        }
}