package airlift.test.util;

/**
 * Title:        AirLift Framework for Java - Test Project
 * Description:  A concrete Enumerate extension for purposes of testing airlift.util.Enumerate.
 * Copyright:    Copyright (c) 2002
 *                  Note: this file is hereby released for reference use
 *                  to participants in the Middle Tennessee Java Users Group.
 * Company:      The AirLift Team
 * @author       Mark Soileau
 * @version      1.0
 */

import airlift.util.Enumerate;
import java.util.*;


public class ViewportRoles extends Enumerate
{
    private static List sEnumerateList = (List) new ArrayList();

    public static final ViewportRoles IDENTITY =
             new ViewportRoles(".");

    public static final ViewportRoles PARENT_VIEWPORT =
             new ViewportRoles("..");

    public static final ViewportRoles SEARCH =
             new ViewportRoles("SEARCH");

    public static final ViewportRoles RESULTS =
             new ViewportRoles("RESULTS");

    public static final ViewportRoles LIST =
             new ViewportRoles("LIST");

    public static final ViewportRoles DETAIL =
             new ViewportRoles("DETAIL");


     // The ALL instance gives access to findByName or Iterate across all ViewportRoles, etc.
    public static final ViewportRoles ALL
                             = new ViewportRoles();

    // this line is important as the last static section of code here
    // as it makes the internal enumerate list unmodifyable such that other
    // classes in this package are not allowed to modify the enumerate list
    static {sEnumerateList = Collections.unmodifiableList(sEnumerateList);}

    private ViewportRoles()
        {
        super();
        }

    /**
     * Construct a new instance of ViewportRoles for use in describing
     * and navigating composite Viewports within the Applicaton Engine.
     */
    private ViewportRoles(String pViewportRoleString)
        {
         // call super constructor with pViewportRoleString as enum name
        super(pViewportRoleString);

        // index automatically assigned by parent class Enumerate
        }

    protected List getConcreteEnumList()
        {
        return sEnumerateList;
        }
}