package airlift.test.util;

/**
 * Title:        AirLift Framework for Java - Test Project
 * Description:  A concrete Enumerate extension for purposes of testing airlift.util.Enumerate.
 * Copyright:    Copyright (c) 2002
 *                  Note: this file is hereby released for reference use
 *                  to participants in the Middle Tennessee Java Users Group.
 * Company:      The AirLift Team
 * @author       Mark Soileau
 * @version      1.0
 */

import java.util.*;
import airlift.util.*;

public class WidgetTypes extends Enumerate
{
    private static List sEnumerateList = (List) new ArrayList();

    private Object mDefaultRenderHints;

    public static final WidgetTypes NA =
             new WidgetTypes("NA",null);

    // ########## stock Item Field widget types follow ################

    // ### TEXT ####
    public static final WidgetTypes TEXT_BOX =
             new WidgetTypes("TEXT_BOX",null);

    public static final WidgetTypes TEXT_AREA =
             new WidgetTypes("TEXT_AREA",null);

    public static final WidgetTypes TEXT_BOX_PASSWORD =
             new WidgetTypes("TEXT_BOX_PASSWORD",null);

    // ### BUTTON ####
    public static final WidgetTypes IMAGE_BUTTON =
             new WidgetTypes("IMAGE_BUTTON",null);

    public static final WidgetTypes TEXT_BUTTON =
             new WidgetTypes("TEXT_BUTTON",null);


    // ### IMAGE ####
    public static final WidgetTypes IMAGE =
             new WidgetTypes("IMAGE",null);

    // used by the MenuControl

    public static final WidgetTypes MENU =
             new WidgetTypes("MENU",null);

    public static final WidgetTypes MENU_ITEM =
             new WidgetTypes("MENU_ITEM",null);

    // ### FIELD LEVEL SELECT ####

    public static final WidgetTypes SELECTABLE_LIST =
             new WidgetTypes("SELECT_LIST_FIELD",null);

    public static final WidgetTypes COMBO_BOX =
             new WidgetTypes("COMBO_BOX",null);

    public static final WidgetTypes RADIO_GROUP =
             new WidgetTypes("RADIO_GROUP",null);

    public static final WidgetTypes TOGGLE =
             new WidgetTypes("TOGGLE",null);

    // ########### stock Control widget types follow #################

    public static final WidgetTypes SELECT_LIST =
             new WidgetTypes("SELECT_LIST",null);

    public static final WidgetTypes FORM =
             new WidgetTypes("FORM",null);

    public static final WidgetTypes TABLE =
             new WidgetTypes("TABLE",null);

    public static final WidgetTypes TREE =
             new WidgetTypes("TREE",null);

    // stock Composite Viewport widget types follow

    public static final WidgetTypes TOP_BOTTOM_SPLIT =
             new WidgetTypes("TOP_BOTTOM_SPLIT",null);

    public static final WidgetTypes LEFT_RIGHT_SPLIT =
             new WidgetTypes("LEFT_RIGHT_SPLIT",null);

    public static final WidgetTypes VIEWPORT_STACK =
             new WidgetTypes("VIEWPORT_STACK",null);

    public static final WidgetTypes VIEWPORT_TABS =
             new WidgetTypes("VIEWPORT_TABS",null);

    public static final WidgetTypes VIEWPORT_SEQUENCE =
             new WidgetTypes("VIEWPORT_SEQUENCE",null);


     // The ALL instance gives access to - may not need this
    public static final WidgetTypes ALL
                             = new WidgetTypes();

    // this line is important as the last static section of code here
    // as it makes the internal enumerate list unmodifyable such that other
    // classes in this package are not allowed to modify the enumerate list
    static {sEnumerateList = Collections.unmodifiableList(sEnumerateList);}

    private WidgetTypes()
        {
        super();
        }

    /**
     * Construct a WidgetTypeEnumerate for use in presentation visualizations, etc.
     */
    private WidgetTypes(String pWidgetTypeString,Object pDefaultRenderHints)
        {
         // call super constructor with pWidgetTypeString as enum name
        super(pWidgetTypeString);

        // index automatically assigned by parent class Enumerate

        // assign the optional render hints object
        this.mDefaultRenderHints = pDefaultRenderHints;
        }

    /**
     * Returns the (optional) default RenderHints object stored at the WidgetType level.
     */
    public Object getDefaultRenderHints()
        {
        return this.mDefaultRenderHints;
        }

    protected List getConcreteEnumList()
        {
        return sEnumerateList;
        }
}